@@ -37,4 +37,22 @@ class BootstrapInfoDO(BaseModel):
     cluster_config: ClusterConfigDO
     template: str = 'normal'
     platform: str = 'aliyun'
-    patch_setting: Optional[Dict] = None
\ No newline at end of file
+    patch_setting: Optional[Dict] = None
+
+
+
+class RandomTemplateVariablesDO(BaseModel):
+    variables: List[str]
+    lengths: Optional[List[int]] = None
+
+
+
+class FileTemplateVariablesDO(BaseModel):
+    variables: List[str]
+    path: str
+
+
+
+class FilesTemplateVariablesDO(BaseModel):
+    variables: List[str]
+    paths: List[str]
\ No newline at end of file
