@@ -37,4 +37,22 @@ class BootstrapInfoDTO(BaseModel):
     cluster_config: ClusterConfigDTO
     template: str = 'normal'
     platform: str = 'aliyun'
-    patch_setting: Optional[Dict] = None
\ No newline at end of file
+    patch_setting: Optional[Dict] = None
+
+
+
+class RandomTemplateVariablesDTO(BaseModel):
+    variables: List[str]
+    lengths: Optional[List[int]] = None
+
+
+
+class FileTemplateVariablesDTO(BaseModel):
+    variables: List[str]
+    path: str
+
+
+
+class FilesTemplateVariablesDTO(BaseModel):
+    variables: List[str]
+    paths: List[str]
\ No newline at end of file
