@@ -76,4 +76,37 @@ class BootstrapInfo(Entity):
         self.cluster_config = cluster_config
         self.template = template
         self.platform = platform
-        self.patch_setting = patch_setting
\ No newline at end of file
+        self.patch_setting = patch_setting
+
+
+
+class RandomTemplateVariables(Entity):
+    def __init__(
+        self,
+        variables: List[UStr],
+        lengths: Optional[List[UInt]] = None
+    ) -> None:
+        self.variables = variables
+        self.lengths = lengths
+
+
+
+class FileTemplateVariables(Entity):
+    def __init__(
+        self,
+        variables: List[UStr],
+        path: UStr
+    ) -> None:
+        self.variables = variables
+        self.path = path
+
+
+
+class FilesTemplateVariables(Entity):
+    def __init__(
+        self,
+        variables: List[UStr],
+        paths: List[UStr]
+    ) -> None:
+        self.variables = variables
+        self.paths = paths
\ No newline at end of file
